#
# spec file for package golang-github-prometheus-prometheus
#
# Copyright (c) 2017 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%{go_nostrip}

Name:           golang-github-prometheus-prometheus
Version:        2.1.0
Release:        lp150.1.9
License:        Apache-2.0
Summary:        The Prometheus monitoring system and time series database
Url:            https://prometheus.io/
Group:          System/Management
Source:         prometheus-%{version}.tar.xz
Source1:        prometheus.service
Source2:        prometheus.yml	
Patch1:         0001-Do-not-force-the-pure-Go-name-resolver.patch
# Lifted from Debian's prometheus package
Patch2:         0002-Default-settings.patch
#  Fix loopback address for REST API gateway (v2) #3174 
Patch100:       pr-3174.patch
%ifarch aarch64
# For some reason the aarch64 build fails with:
#   + promu build
#    >   prometheus
#   # github.com/prometheus/prometheus/cmd/prometheus
#   /usr/lib64/go/pkg/tool/linux_arm64/link: running gcc failed: exit status 1
#   /usr/lib64/gcc/aarch64-suse-linux/4.8/../../../../aarch64-suse-linux/bin/ld: cannot find -lpthread
#   /usr/lib64/gcc/aarch64-suse-linux/4.8/../../../../aarch64-suse-linux/bin/ld: cannot find -lc
#   collect2: error: ld returned 1 exit status
# Adding glibc-devel-static fixes it, but it's odd that this isn't
# also a problem on x86_64.
BuildRequires:  glibc-devel-static
%endif
BuildRequires:  fdupes
BuildRequires:  golang-github-prometheus-promu
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
Requires(pre):  shadow
%{go_provides}

%description
Prometheus's main features are:
 - a multi-dimensional data model (time series identified by metric name and key/value pairs)
 - a flexible query language to leverage this dimensionality
 - no reliance on distributed storage; single server nodes are autonomous
 - time series collection happens via a pull model over HTTP
 - pushing time series is supported via an intermediary gateway
 - targets are discovered via service discovery or static configuration
 - multiple modes of graphing and dashboarding support

%prep
%setup -q -n prometheus-%{version}
%patch1 -p 1
%patch2 -p 1
%patch100 -p 1

%build
%goprep github.com/prometheus/prometheus
GOPATH=%{_builddir}/go promu build

%install
%goinstall
install -D -m0755 %{_builddir}/prometheus-%{version}/prometheus %{buildroot}/%{_bindir}/prometheus
install -D -m0755 %{_builddir}/prometheus-%{version}/prometheus %{buildroot}/%{_bindir}/promtool
%gosrc
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/prometheus.service
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcprometheus
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/prometheus/prometheus.yml
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/metrics
%gofilelist
%fdupes %{buildroot}/%{_prefix}

%pre
%service_add_pre prometheus.service
getent group prometheus >/dev/null || %{_sbindir}/groupadd -r prometheus
getent passwd prometheus >/dev/null || %{_sbindir}/useradd -r -g prometheus -d %{_localstatedir}/lib/prometheus -s /sbin/nologin prometheus

%post
%service_add_post prometheus.service

%preun
%service_del_preun prometheus.service

%postun
%service_del_postun prometheus.service

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md LICENSE
%{_bindir}/prometheus
%{_bindir}/promtool
%{_unitdir}/prometheus.service
%{_sbindir}/rcprometheus
%dir %attr(0750, prometheus, prometheus) %{_localstatedir}/lib/prometheus
%dir %attr(0750, prometheus, prometheus) %{_localstatedir}/lib/prometheus/metrics
%dir %{_sysconfdir}/prometheus
%config(noreplace) %{_sysconfdir}/prometheus/prometheus.yml

%changelog
* Wed Mar 14 2018 jan.fajerski@suse.com
- spec: fix directory for fdupes
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 2.1.0:
  + Features:
  * New Service Discovery UI showing labels before and after relabelling.
  * New Admin APIs added to v1 to delete, snapshot and remove tombstones.
  + Enhancements:
  * The graph UI autcomplete now includes your previous queries.
  * Federation is now much faster for large numbers of series.
  * Added new metrics to measure rule timings.
  * Rule evaluation times added to the rules UI.
  * Added metrics to measure modified time of file SD files.
  * Kubernetes SD now includes POD UID in discovery metadata.
  * The Query APIs now return optional stats on query execution times.
  * The index now no longer has the 4GiB size limit and is also smaller.
  + Bug Fixes:
  * Remote read read_recent option is now false by default.
  * Pass the right configuration to each Alertmanager (AM) when using
    multiple AM configs.
  * Fix not-matchers not selecting series with labels unset.
  * tsdb: Fix occasional panic in head block.
  * tsdb: Close files before deletion to fix retention issues on Windows
    and NFS.
  * tsdb: Cleanup and do not retry failing compactions.
  * tsdb: Close WAL while shutting down.
* Thu Nov  9 2017 tserong@suse.com
- Update to final v2.0.0 release (bsc#1067341):
  + Compared to version 1.x, this release includes a completely rewritten
    storage engine, huge performance improvements, but also many backwards
    incompatible changes.  For more information, read the announcement blog
    post and migration guide:
  - https://prometheus.io/blog/2017/11/08/announcing-prometheus-2-0/
  - https://prometheus.io/docs/prometheus/2.0/migration/
  + Changes:
  * Completely rewritten storage layer, with WAL.  This is not backwards
    compatible with 1.x storage,  and many flags have changed/disappeared.
  * New staleness behavior. Series now marked stale after target scrapes
    no longer return them, and soon after targets disappear from service
    discovery.
  * Rules files use YAML syntax now.  Conversion tool added to promtool.
  * Removed count_scalar, drop_common_labels functions and keep_common
    modifier from PromQL.
  * Rewritten exposition format parser with much higher performance.  The
    Protobuf exposition format is no longer supported.
  * Example console templates updated for new storage and metrics names.
    Examples other than node exporter and Prometheus removed.
  * Admin and lifecycle APIs now disabled by default, can be reenabled via
    flags
  * Flags switched to using Kingpin, all flags are now --flagname rather
    than -flagname.
  + Features:
  * Remote read can be configured to not read data which is available
    locally.  This is enabled by default.
  * Rules can be grouped now.  Rules within a rule group are executed
    sequentially.
  * Added experimental GRPC apis
  * Add timestamp() function to PromQL.
  + Enhancements:
  * Remove remote read from the query path if no remote storage is
    configured.
  * Bump Consul HTTP client timeout to not match the Consul SD watch
    timeout.
  * Go-conntrack added to provide HTTP connection metrics.
  + Bug Fixes:
  * Fix connection leak in Consul SD.
* Tue Nov  7 2017 tserong@suse.com
- Update to v2.0.0-rc.3 (bsc#1067030):
  + Enhancements:
  * Remove remote read from the query path if no remote storage
    is configured.
  * Bump Consul HTTP client timeout to not match the Consul SD
    watch timeout.
  * Bump up a too small max block duration to the min block
    duration instead of returning an error.
  + Bug Fixes:
  * Avoid needless padding of 4 zero bytes in index files.
  * Delete old blocks during reload (necessary on MS Windows).
  * Fix regression of alert rules state loss on config reload.
  * Serialize background WAL operations to avoid data races.
  + This also contains bugfixes and remote-storage features from
    the 1.8 branch.
* Fri Oct 27 2017 tserong@suse.com
- Update to v2.0.0-rc.2 (bsc#1065377):
  + Enhancements:
  * Handle WAL segments with corrupted header gracefully
  * Stabilize memory usage during WAL replay
  + Changes:
  * Prefix all storage metrics with prometheus_
  + Bug Fixes:
  * Correctly handle label removal in remote read
  * Fix chunk misalignment causing out-of-order samples
  * Fix connection leak in Consul SD
  * Handle invalid chunk dereferences gracefully
  * Prevent potential deadlock during failing querier construction
* Thu Oct 19 2017 tserong@suse.com
- Update to v2.0.0-rc.1:
  + Features/Enhancements:
  * Added a warning for time-drift between the browser and the
    prometheus-server.
  * Much faster WAL read-back on restart.
  + Bug Fixes:
  * Fixed Remote-read to not drop the first series.
  * Validate recording-rule names.
  * Fix several races.
  * Only close blocks if there are no iterators accessing it.
- Refresh 0002-Default-settings.patch
* Wed Oct 11 2017 tserong@suse.com
- Update to v2.0.0-rc.0:
  + Numerous changes to the new storage layer, the main changes being:
  * Remove `count_scalar`, `keep_common` and `drop_common_labels` functions
  * Breaking change in the index format for better consistency
  * Fix panic due garbage collected mmap'ed strings
  * Fix broken snapshots and admin APIs
  * Send HTTP Accept header when scraping
  * Use the WAL flush interval passed instead of the hardcoded value
  + This release requires a clean storage directory and is not compatible
    with files created by previous beta releases
- Refresh 0002-Default-settings.patch
* Sun Sep 24 2017 tserong@suse.com
- Fix loopback address for REST API gateway (bsc#1059462)
  + Added pr-3174.patch
* Fri Sep 22 2017 tserong@suse.com
- Update to v2.0.0-beta.5:
  + Bug Fixes:
  * Remove deadlock on startup when restoring WAL
  * Fix semantical races resulting in invalid persisted files
  * Correctly read back WAL in certain edge cases
  * Prevent crashes caused by changing metric representations in target's
    /metrics
  + Enhancements:
  * Overall memory usage reduction
  * Serve debugging endpoints while TSDB is loading
  * Healthy endpoint correctly reflects liveness during startup
  * Switch to consistent usage of go-kit/log
  + This release may have issues with files written by previous beta releases
- Refresh 0002-Default-settings.patch to apply cleanly again
* Mon Sep 18 2017 tserong@suse.com
- Update to v2.0.0-beta.4:
  + Numerous changes to the new storage layer, the main changes being:
  * Single, compacted write ahead log
  * Single in-memory block with garbage collection
  * Improve compression of index files
  * Cache series dropped via metric_relabel_configs
  * Pool byte buffers for scraping
  + Overall the changes achieve a baseline reduction in memory consumption
    and reduce peak memory usage by 30-40%% compared to 2.0.0-beta.2
  + This release requires a clean storage directory and is not compatible
    with files created by previous beta releases
* Tue Aug 22 2017 tserong@suse.com
- Update to v2.0.0-beta.2
  + vendor: update prometheus/tsdb (Fix panic caused by 0 division)
* Wed Aug 16 2017 tserong@suse.com
- Update to v2.0.0-beta.1
  + Includes a new storage layer, which reduces bottlenecks and shows
    considerable performance improvements, but does not work with old v1
    storage data.
- Refresh 0002-Default-settings.patch to apply cleanly again
* Tue May  9 2017 tserong@suse.com
- Add systemd unit file and default config (/etc/prometheus/prometheus.yml)
- Run as unprivileged "prometheus" user
- Default to /etc/prometheus for config and /var/lib/prometheus for metrics
  + Added 0002-Default-settings.patch
* Wed Apr 26 2017 tserong@suse.com
- Add BuildRequires: glibc-devel-static to fix aarch64 build
* Wed Mar 29 2017 moio@suse.com
- Initial version
